@@ -2,7 +2,7 @@ import requests
 import json
 
 from .Exceptions import InvalidRequest
-from .Config import _Key
+from .Config import Key
 
 
 def get(url, payload=None):
@@ -25,7 +25,7 @@ def get_v3(request):
 
     :param request: The APIv3 request desired
     """
-    return get(f"https://api.politicsandwar.com/graphql?api_key={_Key}", {"query": request})["data"]
+    return get(f"https://api.politicsandwar.com/graphql?api_key={Key}", {"query": request})["data"]
 
 
 def war_range(score: int):
